# PriceFormat

Specifies whether the tier has a fixed price or a per-unit price. 

## Enum

* `FLATFEE` (value: `'FlatFee'`)

* `PERUNIT` (value: `'PerUnit'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


